<?php

namespace ElementorPro\Modules\DisplayConditions\Conditions;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

use ElementorPro\Modules\DisplayConditions\Conditions\Base\Condition_Base;
use Elementor\Controls_Manager;
use ElementorPro\Modules\DisplayConditions\Classes\Comparator_Provider;
use ElementorPro\Modules\DisplayConditions\Classes\Comparators_Checker;
use ElementorPro\Modules\QueryControl\Module as QueryControlModule;

/**
 * Elementor Post-Type Condition.
 *
 * Set Post Type as a condition
 *
 * @since 1.0.0
 */
class Elementor_Post_Type_Condition extends Condition_Base {

	public function get_name() {
		return 'post_type';
	}

	public function get_group() {
		return 'post';
	}

	public function get_label() {
		return esc_html__( 'Post Type', 'post-type-condition' );
	}

	public function check( $args = [] ) : bool {

		// Get the current post
		$current_post_id = get_the_ID(); // Get the current post ID
		$post = get_post( $current_post_id ); // Fetch the post object
		
		// Get the post type
		$post_type = isset( $post->post_type ) ? $post->post_type : '';

		// Which post types are in the condition arguments
		$post_types = isset( $args['post_types'] ) ? $args['post_types'] : [];
		
		// Because we used a simple select box, args['post_types'] will be a string.
		// The Comparators_Checker however needs an array. So turn it into an array.
		if( !is_array( $post_types ) ) {
			$post_types = [ $post_types ];
		}
		
		$comparator = $args['comparator'];
		$comparator_result = Comparators_Checker::check_array_contains( $comparator, [ $post_type ], $post_types );
		return $comparator_result;
	}

	public function get_options() {
		
		// Available comparators
		$comparators = Comparator_Provider::get_comparators(
			[
				Comparator_Provider::COMPARATOR_IS,
				Comparator_Provider::COMPARATOR_IS_NOT,
			]
		);

		// Add the comparators select field
		$this->add_control(
			'comparator',
			[
				'type' => Controls_Manager::SELECT,
				'options' => $comparators,
				'default' => Comparator_Provider::COMPARATOR_IS,
			]
		);

		// Get all available post_types (including the ones that arent public)
		$post_types = get_post_types();
		
		// Add the selectbox for selecting the post type
		$this->add_control(
			'post_types',
			[
				'type' => Controls_Manager::SELECT,
				'options' => $post_types,
				'default' => 'post',
			]
		);
	}
}